@@ -60,8 +60,10 @@ from troposphere.servicediscovery import (
     Instance as SdInstance,
 )
 
+from ipaddress import IPv4Interface
+
 from ecs_composex.common import add_parameters
-from ecs_composex.common import keyisset, LOG
+from ecs_composex.common import keyisset, LOG, NONALPHANUM
 from ecs_composex.common.cfn_conditions import USE_STACK_NAME_CON_T
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
 from ecs_composex.common.outputs import ComposeXOutput
@@ -88,11 +90,6 @@ from ecs_composex.ecs.ecs_params import (
 from ecs_composex.vpc import vpc_params
 from ecs_composex.vpc.vpc_params import VPC_ID, PUBLIC_SUBNETS
 
-CIDR_REG = r"""((((((([0-9]{1}\.))|([0-9]{2}\.)|
-(1[0-9]{2}\.)|(2[0-5]{2}\.)))){3})(((((([0-9]{1}))|
-([0-9]{2})|(1[0-9]{2})|(2[0-5]{2}))))){1,3})\/(([0-9])|([1-2][0-9])|((3[0-2])))$"""
-CIDR_PAT = re.compile(CIDR_REG)
-
 
 def flatten_ip(ip_str):
     """
@@ -158,7 +155,9 @@ def handle_same_task_services_dependencies(
                 service_config.family_dependents.append(
                     {
                         "ContainerName": dependency,
-                        "Condition": "START"
+                        "Condition": containers_config[dependency][
+                            "config"
+                        ].container_start_condition
                         if not containers_config[dependency]["config"].healthcheck
                         else "HEALTHY",
                     }
@@ -292,15 +291,14 @@ def generate_security_group_props(allowed_source, service_name):
         ),
     }
 
-    if (
-        keyisset("CidrIp", props)
-        and isinstance(props["CidrIp"], str)
-        and not CIDR_PAT.match(props["CidrIp"])
-    ):
-        LOG.error(f"Falty IP Address: {allowed_source} - ecs_service {service_name}")
-        raise ValueError(
-            "Not a valid IPv4 CIDR notation", props["CidrIp"], "Expected", CIDR_REG,
-        )
+    if keyisset("CidrIp", props) and isinstance(props["CidrIp"], str):
+        try:
+            IPv4Interface(props["CidrIp"])
+        except Exception as error:
+            LOG.error(
+                f"Falty IP Address: {allowed_source} - ecs_service {service_name}"
+            )
+            raise ValueError("Not a valid IPv4 CIDR notation", props["CidrIp"], error)
     return props
 
 
@@ -320,9 +318,11 @@ class Service(object):
     def __init__(self, template, family_name, task_definition, config, settings):
         """
         Function to initialize the Service object
+        :param ecs_composex.ecs.ecs_service_config.ServiceConfig config: the configuration for service
         :param family_name: Name of the service
         :type family_name: str
         """
+        self.alb_sg = None
         self.template = template
         self.config = config
         self.task = task_definition
@@ -347,6 +347,7 @@ class Service(object):
             vpc_params.APP_SUBNETS_T: Join(",", Ref(vpc_params.APP_SUBNETS)),
             vpc_params.PUBLIC_SUBNETS_T: Join(",", Ref(vpc_params.PUBLIC_SUBNETS)),
             ecs_params.CLUSTER_NAME_T: Ref(ecs_params.CLUSTER_NAME),
+            ecs_params.LOG_GROUP_RETENTION.title: self.config.logs_retention_period,
         }
         if config.family_name is not None:
             self.parameters.update({ecs_params.SERVICE_NAME_T: config.family_name})
@@ -364,11 +365,85 @@ class Service(object):
         self.generate_service_definition(self.task.definition)
         self.generate_service_template_outputs()
 
+    def add_self_ingress(self, sg):
+        """
+        Method to allow communications internally to the group on set ports
+        :param sg:
+        :return:
+        """
+        for port in self.config.ports:
+            SecurityGroupIngress(
+                f"AllowingMyselfToMyselfOnPort{port['published']}",
+                template=self.template,
+                FromPort=port["published"],
+                ToPort=port["published"],
+                IpProtocol=port["protocol"],
+                GroupId=GetAtt(sg, "GroupId"),
+                SourceSecurityGroupId=GetAtt(sg, "GroupId"),
+                SourceSecurityGroupOwnerId=Ref(AWS_ACCOUNT_ID),
+                Description=Sub(
+                    f"Allowing traffic internally on port {port['published']}"
+                ),
+            )
+
+    def add_aws_sources(self, sg):
+        """
+        Method to add ingress rules from other AWS Sources
+        :param sg:
+        :return:
+        """
+        allowed_keys = ["type", "id"]
+        allowed_types = ["SecurityGroup", "PrefixList"]
+        for source in self.config.aws_sources:
+            if not all(key in allowed_keys for key in source.keys()):
+                raise KeyError(
+                    "Missing ingress properties. Got",
+                    source.keys,
+                    "Expected",
+                    allowed_keys,
+                )
+            if not source["type"] in allowed_types:
+                raise ValueError(
+                    "Invalid type specified. Got",
+                    source["type"],
+                    "Allowed one of ",
+                    allowed_types,
+                )
+            if source["type"] == "SecurityGroup":
+                for port in self.config.ports:
+                    SecurityGroupIngress(
+                        f"From{NONALPHANUM.sub('', source['id'])}ToServiceOn{port['published']}",
+                        template=self.template,
+                        FromPort=port["published"],
+                        ToPort=port["published"],
+                        IpProtocol=port["protocol"],
+                        GroupId=GetAtt(sg, "GroupId"),
+                        SourceSecurityGroupOwnerId=Ref(AWS_ACCOUNT_ID),
+                        SourceSecurityGroupId=source["id"],
+                        Description=Sub(
+                            f"From {source['id']} to ${{{SERVICE_NAME_T}}} on port {port['published']}"
+                        ),
+                    )
+            elif source["type"] == "PrefixList":
+                for port in self.config.ports:
+                    SecurityGroupIngress(
+                        f"From{NONALPHANUM.sub('', source['id'])}ToServiceOn{port['published']}",
+                        template=self.template,
+                        FromPort=port["published"],
+                        ToPort=port["published"],
+                        IpProtocol=port["protocol"],
+                        GroupId=GetAtt(sg, "GroupId"),
+                        SourcePrefixListId=source["id"],
+                        Description=Sub(
+                            f"From {source['id']} to ${{{SERVICE_NAME_T}}} on port {port['published']}"
+                        ),
+                    )
+
     def add_service_default_sg(self):
         """
         Adds a default security group for the microservice.
         """
-        self.template.add_resource(
+        sg = self.template.add_resource(
             SecurityGroup(
                 SG_T,
                 GroupDescription=If(
@@ -390,6 +465,7 @@ class Service(object):
                 VpcId=Ref(VPC_ID),
             )
         )
+        return sg
 
     def add_service_to_map(self):
         """
@@ -424,31 +500,6 @@ class Service(object):
             break
         return registries
 
-    def add_lb_to_service_ingress(self, lb_sg, service_sg):
-        """
-        Method to add ingress rules between the LB and the microservice according to the ports defined by the service.
-
-        :param lb_sg: Load Balancer security group
-        :type lb_sg: troposphere.ec2.SecurityGroup
-        :param service_sg: security group of the microservice
-        :type service_sg: str or troposphere.ec2.SecurityGroup
-        """
-        LOG.debug(f"Adding ALB ingress to ecs_service")
-        for port in self.config.ports:
-            SecurityGroupIngress(
-                f"From{self.config.lb_type.title()}ToServicePort{port['target']}",
-                template=self.template,
-                FromPort=port["target"],
-                ToPort=port["target"],
-                IpProtocol=port["protocol"],
-                GroupId=GetAtt(service_sg, "GroupId"),
-                SourceSecurityGroupOwnerId=Ref(AWS_ACCOUNT_ID),
-                SourceSecurityGroupId=GetAtt(lb_sg, "GroupId"),
-                Description=Sub(
-                    f"From LB to ${{{SERVICE_NAME_T}}} on port {port['target']}"
-                ),
-            )
-
     def create_lb_ingress_rule(self, allowed_source, security_group, **props):
         for port in self.config.ports:
             if keyisset("source_name", allowed_source):
@@ -513,9 +564,17 @@ class Service(object):
         :rtype: list
         """
         for az in azs:
+            if isinstance(az, dict) and keyisset("ZoneName", az):
+                az_name = NONALPHANUM.sub(
+                    "", az["ZoneName"].title().replace("-", "").strip()
+                )
+            elif isinstance(az, str):
+                az_name = NONALPHANUM.sub("", az)
+            else:
+                raise TypeError("az is neither a dict or a str. Got", type(az))
             self.eips.append(
                 EIP(
-                    f"EipPublicNlb{az.replace('-', '').strip()}{self.service_name}",
+                    f"EipPublicNlb{az_name}{self.service_name}",
                     template=self.template,
                     Domain="vpc",
                 )
@@ -533,7 +592,7 @@ class Service(object):
         suffix = "Private"
         if self.config.is_public:
             suffix = "Public"
-        sg = SecurityGroup(
+        self.alb_sg = SecurityGroup(
             f"AlbSecurityGroup{suffix}",
             template=self.template,
             GroupDescription=Sub(
@@ -557,11 +616,10 @@ class Service(object):
                 FromPort=port,
                 ToPort=port,
                 GroupId=GetAtt(SG_T, "GroupId"),
-                SourceSecurityGroupId=GetAtt(sg, "GroupId"),
+                SourceSecurityGroupId=GetAtt(self.alb_sg, "GroupId"),
                 SourceSecurityGroupOwnerId=Ref(AWS_ACCOUNT_ID),
                 IpProtocol="tcp",
             )
-        return sg
 
     def add_lb_listener(self, port, lb, tgt, target_port):
         """
@@ -639,16 +697,14 @@ class Service(object):
         :return: loadbalancer
         :rtype: troposphere.elasticloadbalancingv2.LoadBalancer
         """
-        alb_sg = None
         if self.config.is_public and self.config.use_nlb():
             self.add_public_ips(settings.aws_azs)
 
         no_value = Ref(AWS_NO_VALUE)
         public_mapping = define_public_mapping(self.eips, settings.aws_azs)
         if self.config.ingress_mappings and self.config.use_alb():
-            alb_sg = self.add_alb_sg(self.config.ingress_mappings.keys())
-            # self.add_lb_to_service_ingress(alb_sg, SG_T)
-            lb_sg = [Ref(alb_sg)]
+            self.add_alb_sg(self.config.ingress_mappings.keys())
+            lb_sg = [Ref(self.alb_sg)]
         else:
             lb_sg = no_value
 
@@ -661,15 +717,9 @@ class Service(object):
                     Key="load_balancing.cross_zone.enabled", Value="true"
                 )
             ]
-            if self.config.lb_type == "network"
+            if self.config.use_nlb()
             else no_value,
-            SecurityGroups=lb_sg,
-            SubnetMappings=public_mapping
-            if self.config.is_public and self.config.use_nlb()
-            else no_value,
-            Subnets=Ref(PUBLIC_SUBNETS)
-            if self.config.is_public and self.config.use_alb()
-            else Ref(vpc_params.APP_SUBNETS),
+            SecurityGroups=lb_sg if self.config.use_alb() else no_value,
             Type=self.config.lb_type,
             Tags=Tags(
                 {
@@ -679,6 +729,13 @@ class Service(object):
                 }
             ),
         )
+        if self.config.is_public and self.config.use_alb():
+            setattr(loadbalancer, "Subnets", Ref(PUBLIC_SUBNETS))
+        elif self.config.is_public and self.config.use_nlb():
+            setattr(loadbalancer, "SubnetMappings", public_mapping)
+            setattr(loadbalancer, "Subnets", Ref(AWS_NO_VALUE))
+        elif not self.config.is_public:
+            setattr(loadbalancer, "Subnets", Ref(vpc_params.APP_SUBNETS))
         if self.config.is_public:
             sd_service = SdService(
                 f"{self.resource_name}PublicDiscoveryService",
@@ -703,8 +760,8 @@ class Service(object):
                     "AWS_ALIAS_DNS_NAME": GetAtt(loadbalancer, "DNSName")
                 },
             )
-            if self.config.use_alb() and alb_sg:
-                self.add_public_security_group_ingress(alb_sg)
+            if self.config.use_alb() and self.alb_sg:
+                self.add_public_security_group_ingress(self.alb_sg)
             elif self.config.use_nlb():
                 self.add_public_security_group_ingress(SG_T)
         return loadbalancer
@@ -732,7 +789,7 @@ class Service(object):
                 EcsLoadBalancer(
                     TargetGroupArn=Ref(tgt),
                     ContainerPort=tgt.Port,
-                    ContainerName=self.config.lb_service_name,
+                    ContainerName=NONALPHANUM.sub("", self.config.lb_service_name),
                 )
             )
         return service_lbs, depends_on
@@ -766,7 +823,7 @@ class Service(object):
 
         :param ecs_composex.common.settings.ComposeXSettings settings: Execution settings
         """
-        self.add_service_default_sg()
+        sg = self.add_service_default_sg()
         service_lbs = Ref(AWS_NO_VALUE)
         registries = self.add_service_to_map()
         if not registries:
@@ -787,6 +844,14 @@ class Service(object):
             self.service_attrs["DependsOn"] = (
                 service_lb[-1] if isinstance(service_lb[-1], list) else []
             )
+            if self.config.use_alb() and self.config.aws_sources:
+                self.add_aws_sources(self.alb_sg)
+        elif (
+            self.config.use_nlb() and self.config.aws_sources
+        ) or self.config.aws_sources:
+            self.add_aws_sources(sg)
+        if self.config.ingress_from_self:
+            self.add_self_ingress(sg)
 
     def generate_service_definition(self, task_definition):
         """
