@@ -209,13 +209,13 @@ class ServiceConfig(object):
 
     master_key = "x-configs"
     composex_key = "composex"
-    valid_config_keys = ["network", "iam", "x-ray"]
+    valid_config_keys = ["network", "iam", "x-ray", "logging"]
 
     network_defaults = {
         "use_cloudmap": True,
         "is_public": False,
         "lb_type": None,
-        "ext_sources": None,
+        "ingress": None,
     }
 
     def __init__(self, content, service_name, definition, family_name=None):
@@ -232,14 +232,17 @@ class ServiceConfig(object):
         self.lb_type = None
         self.healthcheck = None
         self.ext_sources = None
+        self.aws_sources = None
+        self.ingress_from_self = False
         self.is_public: False
         self.use_cloudmap = True
         self.use_appmesh = False
         self.boundary = None
         self.policies = []
         self.managed_policies = []
+        self.container_start_condition = "START"
         self.service_name = service_name if service_name else "global"
-
+        self.logs_retention_period = ecs_params.LOG_GROUP_RETENTION.Default
         if keyisset("x-appmesh", content):
             self.use_appmesh = True
 
@@ -355,6 +358,46 @@ class ServiceConfig(object):
             elif key_name == "policies" and isinstance(config["policies"], list):
                 self.add_policies(config["policies"])
 
+    def init_logging(self, config):
+        """
+        Method to handle `logging`
+        :param config:
+        """
+        allowed_keys = ["logs_retention_period"]
+        for key in allowed_keys:
+            if key not in allowed_keys:
+                raise KeyError(
+                    f"{key} not allowed setting for logging. Allowed", allowed_keys
+                )
+            if key in config and key == "logs_retention_period":
+                setattr(
+                    self,
+                    key,
+                    min(
+                        ecs_params.LOG_GROUP_RETENTION.AllowedValues,
+                        key=lambda x: abs(x - config[key]),
+                    ),
+                )
+
+    def parse_ingress(self, ingress_settings):
+        """
+        Method to set the ingress_name for the service.
+        :param ingress_settings:
+        :return:
+        """
+        allowed_keys = ["ext_sources", "aws_sources", "myself"]
+        for ingress_name in ingress_settings:
+            if ingress_name not in allowed_keys:
+                raise ValueError(
+                    f"Setting {ingress_name} is not valid. Allowed", allowed_keys
+                )
+            if ingress_name == "myself" and ingress_settings["myself"]:
+                self.ingress_from_self = True
+            elif ingress_name == "ext_sources":
+                self.ext_sources = ingress_settings[ingress_name]
+            elif ingress_name == "aws_sources":
+                self.aws_sources = ingress_settings[ingress_name]
+
     def init_network(self, config):
         """
         Function to define networking properties
@@ -372,7 +415,10 @@ class ServiceConfig(object):
                 setattr(self, key_name, self.network_defaults[key_name])
             elif key_name in config.keys():
                 LOG.debug(f"ELSE - {key_name}- {config[key_name]}")
-                setattr(self, key_name, config[key_name])
+                if key_name == "ingress":
+                    self.parse_ingress(config[key_name])
+                else:
+                    setattr(self, key_name, config[key_name])
 
     def set_from_top_configs(self, compose_content):
         """
@@ -475,10 +521,21 @@ class ServiceConfig(object):
         """
         if not keyisset("deploy", definition):
             return
+        depends_key = "ecs.depends.condition"
         deployment = definition["deploy"]
         if keyisset("resources", deployment):
             self.set_compute_resources(deployment["resources"])
         self.set_deployment_settings(deployment)
+        if keyisset("labels", deployment) and keyisset(
+            depends_key, deployment["labels"]
+        ):
+            allowed_values = ["START", "COMPLETE", "SUCCESS", "HEALTHY"]
+            if deployment["labels"][depends_key] not in allowed_values:
+                raise ValueError(
+                    f"Attribute {depends_key} is invalid. Must be one of",
+                    allowed_values,
+                )
+            self.container_start_condition = deployment["labels"][depends_key]
 
     def set_xray(self, definition):
         """
