@@ -27,7 +27,7 @@ from ecs_composex.resource_settings import (
     generate_resource_permissions,
     generate_resource_envvars,
 )
-from ecs_composex.sqs.sqs_params import SQS_ARN_T
+from ecs_composex.sqs.sqs_params import SQS_URL, SQS_ARN
 from ecs_composex.sqs.sqs_perms import ACCESS_TYPES
 
 
@@ -56,9 +56,11 @@ def handle_new_queues(
 
     for queue_name in xresources:
         if queue_name in queues_r:
-            perms = generate_resource_permissions(queue_name, ACCESS_TYPES, SQS_ARN_T)
+            perms = generate_resource_permissions(
+                queue_name, ACCESS_TYPES, SQS_ARN.title
+            )
             envvars = generate_resource_envvars(
-                queue_name, xresources[queue_name], SQS_ARN_T
+                queue_name, xresources[queue_name], SQS_URL
             )
             apply_iam_based_resources(
                 xresources[queue_name],
